summaryrefslogtreecommitdiffstats
path: root/src/suspenddialog.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-16 23:01:29 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-16 23:01:29 +0000
commit4304e8d9dab8e20513e38e71b0debdf6937b630c (patch)
tree76a86f013a811449a5b5bfbbbb962e7db0bbcc6a /src/suspenddialog.cpp
parentba24506b3bb46312d998468ad3c1a7f28058b2bd (diff)
downloadtdepowersave-4304e8d9dab8e20513e38e71b0debdf6937b630c.tar.gz
tdepowersave-4304e8d9dab8e20513e38e71b0debdf6937b630c.zip
Finish TQt4 port of kpowersave
This enables both Qt3 and Qt4 builds git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/kpowersave@1228282 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'src/suspenddialog.cpp')
-rw-r--r--src/suspenddialog.cpp26
1 files changed, 13 insertions, 13 deletions
diff --git a/src/suspenddialog.cpp b/src/suspenddialog.cpp
index cb40a74..e76f887 100644
--- a/src/suspenddialog.cpp
+++ b/src/suspenddialog.cpp
@@ -29,19 +29,19 @@
#include <kiconloader.h>
// QT - Headers
- #include <qdialog.h>
- #include <qlabel.h>
- #include <qstring.h>
- #include <qpixmap.h>
- #include <qprogressbar.h>
+ #include <tqdialog.h>
+ #include <tqlabel.h>
+ #include <tqstring.h>
+ #include <tqpixmap.h>
+ #include <tqprogressbar.h>
#include "suspenddialog.h"
/*! This is the default constructor of the class. */
-suspendDialog::suspendDialog(QWidget *parent, const char *name)
- :suspend_Dialog(parent, name, true, Qt::WStyle_StaysOnTop | Qt::WDestructiveClose )
+suspendDialog::suspendDialog(TQWidget *tqparent, const char *name)
+ :suspend_Dialog(tqparent, name, true, TQt::WStyle_StaysOnTop | TQt::WDestructiveClose )
{
- this->setIcon(SmallIcon("kpowersave", QIconSet::Automatic));
+ this->setIcon(SmallIcon("kpowersave", TQIconSet::Automatic));
}
/*! This is the default destructor of the class. */
@@ -52,12 +52,12 @@ suspendDialog::~suspendDialog()
/*!
* This used to set Icon/pixmap for the dialog.
* \param type QString with the type of the current suspend
* to set the pixmap in the dialog
*/
-void suspendDialog::setPixmap( QString type )
+void suspendDialog::setPixmap( TQString type )
{
- QPixmap pixmap = 0;
+ TQPixmap pixmap = 0;
if(type.startsWith("suspend2disk")){// || type.startsWith("NULL")) {
pixmap = KGlobal::iconLoader()->loadIcon("suspend_to_disk", KIcon::NoGroup, KIcon::SizeLarge);
} else if (type.startsWith("suspend2ram")) {
@@ -83,10 +83,10 @@ void suspendDialog::setProgressbar( int percent )
/*!
* This used to set the message of current suspend action to the the dialog.
* \param messageText QString with the message of the current running suspend
* prepare action
*/
-void suspendDialog::setTextLabel( QString messageText )
+void suspendDialog::setTextLabel( TQString messageText )
{
message->show();
message->setText(messageText);
@@ -52,12 +52,12 @@ suspendDialog::~suspendDialog()
/*!
* This used to set Icon/pixmap for the dialog.
- * \param type QString with the type of the current suspend
+ * \param type TQString with the type of the current suspend
* to set the pixmap in the dialog
*/
@@ -83,10 +83,10 @@ void suspendDialog::setProgressbar( int percent )
/*!
* This used to set the message of current suspend action to the the dialog.
- * \param messageText QString with the message of the current running suspend
+ * \param messageText TQString with the message of the current running suspend
* prepare action
*/